lock_file_for_metadata

Function lock_file_for_metadata 

pub fn lock_file_for_metadata(metadata_path: &Path) -> PathBuf
The blessed lock-file path for a metadata file (#100): {metadata-stem}.lock next to it — ds__g1_metadata.json locks through ds__g1_metadata.lock. All cooperating writers of the same metadata file must resolve the lock through this function so the convention holds.