#[non_exhaustive]pub enum StorageError {
Io(String),
Serde(Error),
Parquet(String),
Invalid(String),
Lance(String),
QueryError(String),
InvalidState(String),
UnsupportedFormat(String),
UnsupportedFiletype(String),
DimensionMismatch {
expected: String,
found: String,
},
Overflow(String),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(String)
Serde(Error)
Parquet(String)
Invalid(String)
Lance(String)
QueryError(String)
InvalidState(String)
A storage resource is in an unexpected state (e.g. the metadata path
passed to a save_* call does not match the instance metadata path).
UnsupportedFormat(String)
A filetype does not map to a known storage format.
UnsupportedFiletype(String)
A key/filetype is not recognised as one of the supported file types.
DimensionMismatch
Dimensions recorded in schema metadata do not match the dimensions recorded in storage metadata.
Overflow(String)
A numeric value exceeds the range of the storage type it is written to.