#[repr(i32)]pub enum Encoding {
None = 0,
Plain = 1,
VarBinary = 2,
Dictionary = 3,
Rle = 4,
}Expand description
Supported encodings.
Variants
None = 0
Invalid encoding.
Plain = 1
Plain encoding.
VarBinary = 2
Var-length binary encoding.
Dictionary = 3
Dictionary encoding.
Rle = 4
Run-length encoding.
Implementations
Sourceimpl Encoding
impl Encoding
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.