pub struct BasePath {
pub id: u32,
pub name: Option<String>,
pub is_dataset_root: bool,
pub path: String,
}Expand description
external dataset base path
Fields
id: u32name: Option<String>This is an alias name of the base path, it is optional. When we use shallow clone and the target version is a tag, the tag name will be set here.
is_dataset_root: boolFlag indicating whether this path is a dataset root path or file directory:
- true: Path is a dataset root (actual files under subdirectories like
data, ‘_deletions’) - false: Path is a direct file directory (scenario like importing files)
path: StringNote: This absolute path will be directly used by Path:parse(),
Implementations