pub struct ExternalFile {
pub path: String,
pub offset: u64,
pub size: u64,
}Fields
path: StringPath to the file, relative to the root of the table.
offset: u64The byte offset in the file where the data starts.
size: u64The size of the data in the file, in bytes.