pub struct Transaction {
pub read_version: u64,
pub uuid: String,
pub tag: String,
pub transaction_properties: HashMap<String, String>,
pub operation: Option<Operation>,
}Expand description
A transaction represents the changes to a dataset.
This has two purposes:
- When retrying a commit, the transaction can be used to re-build an updated manifest.
- When there’s a conflict, this can be used to determine whether the other transaction is compatible with this one.
Fields
read_version: u64The version of the dataset this transaction was built from.
For example, for a delete transaction this means the version of the dataset that was read from while evaluating the deletion predicate.
uuid: StringThe UUID that unique identifies a transaction.
tag: StringOptional version tag.
transaction_properties: HashMap<String, String>Optional properties for the transaction __lance_commit_message is a reserved key
operation: Option<Operation>The operation of this transaction.