pub struct FileInfo {
pub filename: String,
pub filetype: String,
pub storage_format: String,
pub rows: usize,
pub cols: usize,
pub nnz: Option<usize>,
pub size_bytes: Option<u64>,
}Expand description
Represent a single file spec in the persistence directory
Fields
filename: Stringname of the file, can be equal to filetype if there is only one per type
filetype: Stringsee Self::which_filetype(..): “rawinput” | “sub_centroids” | “lambdas” | “…”
storage_format: Stringsee Self::which_format(..)
rows: usizecols: usizennz: Option<usize>size_bytes: Option<u64>Implementations
Sourceimpl FileInfo
impl FileInfo
Sourcepub fn new(
filename: String,
filetype: &str,
data_shape: (usize, usize),
nnz: Option<usize>,
size_bytes: Option<u64>,
) -> StorageResult<Self>
pub fn new( filename: String, filetype: &str, data_shape: (usize, usize), nnz: Option<usize>, size_bytes: Option<u64>, ) -> StorageResult<Self>
Create a file spec to add to the persistence directory
Fails with StorageError::UnsupportedFormat for unrecognised
filetypes instead of panicking (issue #45).
Sourcepub fn which_format(filetype: &str) -> StorageResult<String>
pub fn which_format(filetype: &str) -> StorageResult<String>
Assign the right format to the file type
Sourcepub fn which_filetype(filetype: &str) -> StorageResult<String>
pub fn which_filetype(filetype: &str) -> StorageResult<String>
Assign the right filetype to the keyname of the file